@@ -6,10 +6,11 @@ import ruamel.yaml
 import tabulate
 from janis_core import InputQualityType
 
-from janis_core.translationdeps.supportedtranslations import SupportedTranslations
+from janis_core.translationdeps.supportedtranslations import SupportedTranslation
 
 from janis_assistant.__meta__ import DOCS_URL
 from janis_assistant.templates.templates import get_template_names
+from janis_assistant.engines import Cromwell
 from janis_assistant.engines.enginetypes import EngineType
 from janis_assistant.management.configuration import JanisConfiguration
 
@@ -177,6 +178,22 @@ def add_logger_args(parser):
 
 def add_watch_args(parser):
     parser.add_argument("wid", help="Workflow id")
+    parser.add_argument(
+        "--once",
+        help="rather than polling, determine the status of jobs once only",
+        action="store_true",
+    )
+    parser.add_argument(
+        "--refresh", help="time in seconds between refreshes", type=int, default=3
+    )
+    parser.add_argument(
+        "--brief",
+        help="if all the sub-tasks of a task have completed, just show line for the task, not its sub-tasks as well",
+        action="store_true",
+    )
+    parser.add_argument(
+        "--monochrome", help="produce non-colour text only", action="store_true"
+    )
     return parser
 
 
@@ -242,7 +259,7 @@ def add_translate_args(parser):
     parser.add_argument(
         "translation",
         help="language to translate to",
-        choices=SupportedTranslations.all(),
+        choices=SupportedTranslation.all(),
     )
     parser.add_argument(
         "--name",
@@ -258,19 +275,33 @@ def add_translate_args(parser):
         help="Force re-download of workflow if remote",
         action="store_true",
     )
-    parser.add_argument(
+    container_args = parser.add_argument_group("container related args")
+
+    container_args.add_argument(
         "--allow-empty-container",
         action="store_true",
         help="Some tools you use may not include a container, this would usually (and intentionally) cause an error. "
         "Including this flag will disable this check, and empty containers can be used.",
     )
 
-    parser.add_argument(
+    container_args.add_argument(
         "--container-override",
         help="Override a tool's container by specifying a new container. This argument should be specified in the "
         "following (comma separated) format: t1=v1,t2=v2. Eg toolid=container/override:version,toolid2=<container>.",
     )
 
+    container_args.add_argument(
+        "--skip-digest-lookup",
+        action="store_true",
+        help="Janis will not lookup and replace the container digests (sha256 hash).",
+    )
+    container_args.add_argument(
+        "--skip-digest-cache",
+        action="store_true",
+        help="(UNIMPLEMENTED) Janis won't use the digest cache to lookup containers. This cache is shared between tasks "
+        "($JANIS_CONFIGDIR/janis.db) so it might cause locking issues if you run lots of workflows at once",
+    )
+
 
 def add_inputs_args(parser):
     from janis_core import HINTS, HintEnum
@@ -295,9 +326,9 @@ def add_inputs_args(parser):
 
     input_manip_args.add_argument(
         "-r",
-        "--recipes",
+        "--recipe",
         help="If you have values available from these recipes, they will be ignored from the output",
-        nargs="+",
+        action="append",
     )
 
     input_manip_args.add_argument(
@@ -399,19 +430,6 @@ def add_run_args(parser):
 
     # development settings
 
-    parser.add_argument(
-        "--allow-empty-container",
-        action="store_true",
-        help="Some tools you use may not include a container, this would usually (and intentionally) cause an error. "
-        "Including this flag will disable this check, and empty containers can be used.",
-    )
-
-    parser.add_argument(
-        "--container-override",
-        help="Override a tool's container by specifying a new container. This argument should be specified in the "
-        "following (comma separated) format: t1=v1,t2=v2. Eg toolid=container/override:version,toolid2=<container>.",
-    )
-
     parser.add_argument(
         "--development",
         action="store_true",
@@ -469,6 +487,35 @@ def add_run_args(parser):
         action="store_true",
     )
 
+    # container lookups
+
+    container_args = parser.add_argument_group("container related args")
+
+    container_args.add_argument(
+        "--allow-empty-container",
+        action="store_true",
+        help="Some tools you use may not include a container, this would usually (and intentionally) cause an error. "
+        "Including this flag will disable this check, and empty containers can be used.",
+    )
+
+    container_args.add_argument(
+        "--container-override",
+        help="Override a tool's container by specifying a new container. This argument should be specified in the "
+        "following (comma separated) format: t1=v1,t2=v2. Eg toolid=container/override:version,toolid2=<container>.",
+    )
+
+    container_args.add_argument(
+        "--skip-digest-lookup",
+        action="store_true",
+        help="Janis will not lookup and replace the container digests (sha256 hash).",
+    )
+    container_args.add_argument(
+        "--skip-digest-cache",
+        action="store_true",
+        help="(UNIMPLEMENTED) Janis won't use the digest cache to lookup containers. This cache is shared between tasks "
+        "($JANIS_CONFIGDIR/janis.db) so it might cause locking issues if you run lots of workflows at once",
+    )
+
     engine_args = parser.add_argument_group("engine arguments")
 
     engine_args.add_argument(
@@ -596,7 +643,7 @@ def check_logger_args(args):
 
 
 def add_init_args(args):
-    args.add_argument("-r", "--recipes", help="Recipes from template", nargs="+")
+    args.add_argument("-r", "--recipe", help="Recipes from template", action="append")
     args.add_argument("--stdout", action="store_true", help="Write to standard out")
     args.add_argument(
         "-f", "--force", help="Overwrite the template if it exits", action="store_true"
@@ -606,6 +653,11 @@ def add_init_args(args):
         "--output",
         help="Location to overwrite to, defaults to: ~/.janis/janis.conf",
     )
+    args.add_argument(
+        "--ensure-cromwell",
+        action="store_true",
+        help="download cromwell if it is not already present",
+    )
 
     args.add_argument("template", choices=get_template_names())
 
@@ -621,6 +673,9 @@ def do_init(args):
         output_location=args.output,
         force=args.force,
     )
+    if args.ensure_cromwell:
+        cromwell_loc = Cromwell.resolve_jar(None)
+        Logger.info("Located Cromwell at: " + str(cromwell_loc))
 
 
 def do_version(_):
@@ -661,8 +716,15 @@ def do_docs(args):
 
 def do_watch(args):
     wid = args.wid
+    refresh = args.refresh
+    if args.once:
+        # --once overrides --refresh
+        refresh = -1
+    brief = args.brief
+    monochrome = args.monochrome
+
     tm = ConfigManager.manager().from_wid(wid, readonly=True)
-    tm.watch()
+    tm.watch(seconds=refresh, brief=brief, monochrome=monochrome)
 
 
 def do_resume(args):
@@ -788,6 +850,8 @@ def do_run(args):
         allow_empty_container=args.allow_empty_container,
         check_files=not args.skip_file_check,
         container_override=parse_container_override_format(args.container_override),
+        skip_digest_lookup=args.skip_digest_lookup,
+        skip_digest_cache=args.skip_digest_cache,
     )
 
     Logger.info("Exiting")
@@ -806,7 +870,7 @@ def do_spider(args):
 
 def do_inputs(args):
 
-    if args.config or args.recipes:
+    if args.config or args.recipe:
         JanisConfiguration.initial_configuration(args.config)
 
     quality_type = None
@@ -830,7 +894,7 @@ def do_inputs(args):
         additional_inputs=args.inputs,
         with_resources=args.resources,
         quality_type=quality_type,
-        recipes=args.recipes,
+        recipes=args.recipe,
         hints=hints,
     )
 
@@ -888,7 +952,8 @@ def do_query(args):
 def do_rawquery(args):
     wid = args.wid
     wm = ConfigManager.manager().from_wid(wid, readonly=True)
-    result = wm.database.cursor.execute(args.query).fetchall()
+    with wm.database.with_cursor() as cursor:
+        result = cursor.execute(args.query).fetchall()
     return print(tabulate.tabulate(result))
 
 
@@ -924,6 +989,8 @@ def do_translate(args):
         force=args.no_cache,
         allow_empty_container=args.allow_empty_container,
         container_override=container_override,
+        skip_digest_lookup=args.skip_digest_lookup,
+        skip_digest_cache=args.skip_digest_cache,
     )
 
 
