@@ -4,7 +4,7 @@ from janis_assistant.data.dbproviderbase import DbProviderBase
 
 
 # different to archivable
-from janis_assistant.utils import Logger
+from janis_assistant.utils import Logger, fully_qualify_filename
 
 
 class TaskRow:
@@ -48,38 +48,43 @@ class TasksDbProvider(DbProviderBase):
         )"""
 
     def get_by_wid(self, wid) -> Optional[TaskRow]:
-        row = self.cursor.execute(
-            f"SELECT * FROM {TasksDbProvider.table_name} WHERE wid = ?", (wid,)
-        ).fetchone()
+        with self.with_cursor() as cursor:
+            row = cursor.execute(
+                f"SELECT * FROM {TasksDbProvider.table_name} WHERE wid = ?", (wid,)
+            ).fetchone()
         if row is None or len(row) == 0:
             return None
 
         return TaskRow.from_row(row)
 
     def get_all_tasks(self) -> [TaskRow]:
-        return [
-            TaskRow.from_row(r)
-            for r in self.cursor.execute(
+        with self.with_cursor() as cursor:
+            rows = cursor.execute(
                 f"SELECT * FROM {TasksDbProvider.table_name}"
             ).fetchall()
-        ]
+
+        return [TaskRow.from_row(r) for r in rows]
 
     def insert_task(self, task: TaskRow) -> None:
         insfields = TaskRow.insert_fields()
         str_insfields = ",".join(insfields)
         str_insplaceholder = ["?"] * len(insfields)
 
-        self.cursor.execute(
-            f"INSERT INTO {TasksDbProvider.table_name}({str_insfields}) VALUES ({', '.join(str_insplaceholder)})",
-            task.to_row(),
-        )
+        with self.with_cursor() as cursor:
+            cursor.execute(
+                f"INSERT INTO {TasksDbProvider.table_name}({str_insfields}) VALUES ({', '.join(str_insplaceholder)})",
+                task.to_row(),
+            )
+
         self.commit()
 
     def remove_by_id(self, wid: str) -> None:
         Logger.info(f"Removing '{wid}' from database")
-        self.cursor.execute(
-            f"DELETE FROM {TasksDbProvider.table_name} WHERE wid = ?", (wid,)
-        )
+        with self.with_cursor() as cursor:
+            cursor.execute(
+                f"DELETE FROM {TasksDbProvider.table_name} WHERE wid = ?", (wid,)
+            )
+
         self.commit()
 
     def remove_by_ids(self, wids: List[str]) -> None:
@@ -88,7 +93,9 @@ class TasksDbProvider(DbProviderBase):
 
         Logger.info("Removing ids: " + ", ".join(wids))
         seq = ", ".join(["?"] * len(wids))
-        self.cursor.execute(
-            f"DELETE FROM {TasksDbProvider.table_name} WHERE wid in ({seq})", wids
-        )
+        with self.with_cursor() as cursor:
+            cursor.execute(
+                f"DELETE FROM {TasksDbProvider.table_name} WHERE wid in ({seq})", wids
+            )
+
         self.commit()
