@@ -78,6 +78,8 @@ class CromwellConfiguration(Serializable):
         '${sub(sub(cwd, ".*call-", ""), "/", "-")}-cpu-${cpu}-mem-${memory_mb}'
     )
 
+    CATCH_ERROR_COMMAND = '[ ! -f rc ] && (echo 1 >> ${cwd}/execution/rc) && (echo "A slurm error occurred" >> ${cwd}/execution/stderr)'
+
     class Webservice(Serializable):
         def __init__(
             self, port=None, interface=None, binding_timeout=None, instance_name=None
@@ -194,6 +196,7 @@ class CromwellConfiguration(Serializable):
                 user=None,
                 password=None,
                 num_threads=None,
+                maxConnections=None,
             ):
                 self.driver = driver
                 self.url = url
@@ -201,6 +204,7 @@ class CromwellConfiguration(Serializable):
                 self.password = password
                 self.connectionTimeout = connection_timeout
                 self.num_threads = num_threads
+                self.maxConnections = maxConnections
 
         def __init__(self, profile=None, insert_batch_size=None, db: Db = None):
             self.db = db
@@ -219,6 +223,7 @@ class CromwellConfiguration(Serializable):
             connection_timeout=5000,
             database="cromwell",
             url="127.0.0.1",
+            maxConnections=None,
         ):
             return cls(
                 profile="slick.jdbc.MySQLProfile$",
@@ -228,6 +233,7 @@ class CromwellConfiguration(Serializable):
                     user=username,
                     password=password,
                     connection_timeout=connection_timeout,
+                    maxConnections=maxConnections,
                 ),
             )
 
@@ -240,8 +246,9 @@ class CromwellConfiguration(Serializable):
                     url=f"""\
 jdbc:hsqldb:file:{location};
 shutdown=false;
-hsqldb.default_table_type=cached;hsqldb.tx=mvcc;
-hsqldb.result_max_memory_rows=10000;
+hsqldb.default_table_type=cached;
+hsqldb.tx=mvcc;
+hsqldb.result_max_memory_rows=2500;
 hsqldb.large_data=true;
 hsqldb.applog=1;
 hsqldb.lob_compressed=true;
@@ -273,7 +280,17 @@ hsqldb.script_format=3
                             "check_sibling_md5": "check-sibling-md5",
                         }
 
-                    def __init__(self, enabled: bool = True, caching: Caching = None):
+                    def __init__(
+                        self,
+                        enabled: bool = True,
+                        caching: Caching = None,
+                        localization=None,
+                    ):
+                        self.localization = (
+                            localization
+                            if localization is not None
+                            else ["hard-link", "cached-copy"]
+                        )
                         self.enabled = enabled
                         self.caching = caching
 
@@ -290,7 +307,8 @@ hsqldb.script_format=3
                                         "soft-link",
                                     ],
                                     hashing_strategy=(cache_method or "file"),
-                                )
+                                ),
+                                localization=["hard-link", "cached-copy"],
                             )
                         }
 
@@ -399,7 +417,7 @@ String? docker""".strip(),
 
                 afternotokaycommand = ""
                 if afternotokaycatch:
-                    afternotokaycommand = " && NTOKDEP=$(sbatch --parsable --kill-on-invalid-dep=yes --dependency=afternotokay:$JOBID --wrap 'echo 1 >> ${cwd}/execution/rc')"
+                    afternotokaycommand = f" && NTOKDEP=$(sbatch --parsable --kill-on-invalid-dep=yes --dependency=afternotokay:$JOBID --wrap '{CromwellConfiguration.CATCH_ERROR_COMMAND}')"
 
                 partitions = (
                     ",".join(jobqueues) if isinstance(jobqueues, list) else jobqueues
@@ -418,7 +436,7 @@ String? docker
 """
                 slurm.config.submit = None
                 slurm.config.submit_docker = f"""\
-            {singularityloadinstructions}
+            {singularityloadinstructions or ''}
 
             docker_subbed=$(sed -e 's/[^A-Za-z0-9._-]/_/g' <<< ${{docker}})
             image={singularitycontainerdir}/$docker_subbed.sif
@@ -538,7 +556,7 @@ String? docker
 
                 afternotokaycommand = ""
                 if afternotokaycatch:
-                    afternotokaycommand = " && NTOKDEP=$(echo 'echo 1 >> ${cwd}/execution/rc' | qsub -m p -W depend=afternotok:$JOBID -l nodes=1:ppn=1,mem=1GB,walltime=00:01:00)"
+                    afternotokaycommand = f" && NTOKDEP=$(echo '{CromwellConfiguration.CATCH_ERROR_COMMAND}' | qsub -m p -W depend=afternotok:$JOBID -l nodes=1:ppn=1,mem=1GB,walltime=00:01:00)"
                 qparam = ""
                 if queues:
                     qparam = "-q " + (
@@ -695,6 +713,11 @@ String? docker
                 )
             self.hash_lookup = hash_lookup
 
+        @classmethod
+        def default(cls):
+            return None
+            # return cls(hash_lookup=cls.HashLookup(enabled=False))
+
         key_map = {"hash_lookup": "hash-lookup"}
 
     class CallCaching(Serializable):
@@ -730,7 +753,7 @@ String? docker
         database: Database = None,
         backend: Backend = None,
         engine: Engine = None,
-        docker: Docker = None,
+        docker: Docker = Docker.default(),
         cache: CallCaching = None,
         aws=None,
     ):
