@@ -218,6 +218,7 @@ class Cromwell(Engine):
         self._process = subprocess.Popen(
             cmd,
             stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
             # preexec_fn creates a process group https://stackoverflow.com/a/4791612/
             preexec_fn=os.setsid,
         )
@@ -233,15 +234,16 @@ class Cromwell(Engine):
             self._process.stdout.readline, "b"
         ):  # replace '' with b'' for Python 3
 
+            line = None if not c else c.decode("utf-8").rstrip()
+
             rc = self._process.poll()
             if rc is not None:
+                critical_suffix = f"Last received message '{line}'. "
                 Logger.critical(
-                    f"Cromwell has exited with rc={rc}. The last lines of the logfile ({self.logfile}):"
+                    f"Cromwell has exited with rc={rc}. {critical_suffix}The last lines of the logfile ({self.logfile}):"
                 )
                 Logger.critical(tail(self._logfp, 10))
-                return
-
-            line = c.decode("utf-8").rstrip()
+                return False
 
             if not line:
                 continue
@@ -414,7 +416,8 @@ class Cromwell(Engine):
         time = 6
         threading.Timer(time, self.poll_metadata).start()
 
-    def resolve_jar(self, cromwelljar):
+    @staticmethod
+    def resolve_jar(cromwelljar):
         from janis_assistant.management.configuration import JanisConfiguration
 
         man = JanisConfiguration.manager()
@@ -424,22 +427,20 @@ class Cromwell(Engine):
                 f"likely an error, and you should raise an issue at {ISSUE_URL}"
             )
 
-        potentials = []
-
+        if cromwelljar and os.path.exists(cromwelljar):
+            return cromwelljar
+        if man.cromwell.jarpath and os.path.exists(man.cromwell.jarpath):
+            return man.cromwell.jarpath
         fromenv = EnvVariables.cromwelljar.resolve(False)
+        if fromenv and os.path.exists(fromenv):
+            return fromenv
 
-        if cromwelljar:
-            potentials.append(os.path.expanduser(cromwelljar))
-        if man.cromwell.jarpath:
-            potentials.append(os.path.expanduser(man.cromwell.jarpath))
-        if fromenv:
-            potentials.append(fromenv)
-        potentials.extend(
-            reversed(sorted(glob(os.path.join(man.configdir + "cromwell-*.jar"))))
+        potentials = reversed(
+            sorted(glob(os.path.join(man.configdir + "cromwell-*.jar")))
         )
 
         valid_paths = [p for p in potentials if os.path.exists(p)]
-        if len(potentials) > 0:
+        if len(valid_paths) > 0:
             if len(valid_paths) == 0:
                 raise Exception(
                     "Couldn't find cromwelljar at any of the required paths: "
@@ -481,7 +482,7 @@ class Cromwell(Engine):
                     else:
                         print("\rCompleted download of cromwell", file=sys.stderr)
 
-            cromwellurl, cromwellfilename = self.get_latest_cromwell_url()
+            cromwellurl, cromwellfilename = Cromwell.get_latest_cromwell_url()
             Logger.info(
                 f"Couldn't find cromwell at any of the usual spots, downloading '{cromwellfilename}' now"
             )
@@ -526,7 +527,7 @@ class Cromwell(Engine):
             )
 
         if not outs:
-            return {}
+            return None
         parsed = [self.parse_output(k, v) for k, v in outs.items()]
         return {out[0]: out[1] for out in parsed}
 
