@@ -1,4 +1,5 @@
 import sqlite3
+from contextlib import contextmanager
 from os.path import join as ospathjoin
 
 from typing import List
@@ -6,6 +7,7 @@ from typing import List
 from janis_assistant.data.enums import TaskStatus
 from janis_assistant.data.models.workflow import WorkflowModel
 from janis_assistant.data.models.workflowjob import WorkflowJobModel
+from janis_assistant.data.providers.inputsdbprovider import InputDbProvider
 from janis_assistant.data.providers.jobdbprovider import JobDbProvider
 from janis_assistant.data.providers.outputdbprovider import OutputDbProvider
 from janis_assistant.data.providers.progressdbprovider import ProgressDbProvider
@@ -62,11 +64,23 @@ class WorkflowDbManager:
             sqlpath, wid=wid, readonly=readonly
         )
         self.progressDB = ProgressDbProvider(db=self.connection, wid=wid)
-
         self.outputsDB = OutputDbProvider(db=self.connection, wid=wid)
         self.jobsDB = JobDbProvider(db=self.connection, wid=wid)
+        self.inputsDB = InputDbProvider(db=self.connection, wid=wid)
+
         self.versionsDB = VersionsDbProvider(dblocation=sqlpath, readonly=readonly)
 
+    @contextmanager
+    def with_cursor(self):
+        cursor = None
+        try:
+            cursor = self.connection.cursor()
+            yield cursor
+        finally:
+            # Change back up
+            if cursor:
+                cursor.close()
+
     @staticmethod
     def get_workflow_metadatadb(execpath, wid, readonly=False):
 
@@ -144,6 +158,14 @@ class WorkflowDbManager:
 
     def get_metadata(self):
         jobs = self.jobsDB.get_all_mapped()
+        if jobs is None:
+            Logger.log(
+                f"Jobs list for {self.workflowmetadata.wid} was None, skipping this time."
+            )
+            return None
+
+        inputs = self.inputsDB.get_all()
+
         return WorkflowModel(
             wid=self.workflowmetadata.wid,
             engine_wid=self.workflowmetadata.engine_wid,
@@ -166,6 +188,7 @@ class WorkflowDbManager:
                 if self.workflowmetadata.status == TaskStatus.COMPLETED
                 else None
             ),
+            inputs=inputs,
         )
 
     def flatten_jobs(self, jobs: List[WorkflowJobModel]):
