@@ -131,8 +131,8 @@ class WorkflowManager:
 
         return metadb if has else False
 
-    def watch(self):
-        self.show_status_screen()
+    def watch(self, **kwargs):
+        self.show_status_screen(**kwargs)
 
     @staticmethod
     def from_janis(
@@ -154,6 +154,9 @@ class WorkflowManager:
         allow_empty_container=False,
         container_override: dict = None,
         check_files=True,
+        skip_digest_lookup=False,
+        skip_digest_cache=False,
+        **kwargs,
     ):
 
         jc = JanisConfiguration.manager()
@@ -198,6 +201,8 @@ class WorkflowManager:
             allow_empty_container=allow_empty_container,
             container_override=container_override,
             check_files=check_files,
+            skip_digest_lookup=skip_digest_lookup,
+            skip_digest_cache=skip_digest_cache,
         )
 
         outdir_workflow = tm.get_path_for_component(
@@ -313,18 +318,31 @@ class WorkflowManager:
         wid = WorkflowDbManager.get_latest_workflow(path=path)
         return WorkflowManager.from_path_with_wid(path, wid, readonly=readonly)
 
-    def show_status_screen(self):
+    def show_status_screen(self, **kwargs):
         """
         This function just polls the database for metadata every so often,
         and simply displays it. It will keep doing that until the task
         moves into a TERMINAL status.
 
-        It's presumed that there's a janis-monitor that's watching the engine
+        It's presumed that there's a janis-monitor that's watching the engine.
+
+        The kwargs argument is for passing through formatting/refresh options
+        through from the command-line.
         """
 
         if self.database.progressDB.has(ProgressKeys.workflowMovedToFinalState):
+
             meta = self.database.get_metadata()
-            formatted = meta.format()
+            for idx in range(1, 6):
+                if meta is not None:
+                    break
+                Logger.info(
+                    f"Couldn't get metadata from DB, sleeping for a second then will try again {5 - idx} times"
+                )
+                time.sleep(1)
+                meta = self.database.get_metadata()
+
+            formatted = meta.format(**kwargs)
             print(formatted)
             return Logger.debug(f"Workflow '{self.wid}' has already finished, skipping")
 
@@ -345,27 +363,36 @@ class WorkflowManager:
         if bl is not None:
             self.poll_stored_metadata_with_blessed(bl)
         else:
-            self.poll_stored_metadata_with_clear()
+            self.poll_stored_metadata_with_clear(**kwargs)
 
     def get_meta_call(self):
         meta = self.database.get_metadata()
+        if meta is None:
+            return None, False
+
         return meta, meta and meta.status in TaskStatus.final_states()
 
-    def poll_stored_metadata_with_clear(self, seconds=3):
-        is_finished = False
+    def poll_stored_metadata_with_clear(self, seconds=3, **kwargs):
+        try:
+            is_finished = False
 
-        # We won't clear the screen if we haven't printed (first loop) and it's finished
-        has_printed = False
-        while not is_finished:
-            meta, is_finished = self.get_meta_call()
-            if meta:
-                if has_printed or not is_finished:
-                    call("clear")
-                print(meta.format())
-                has_printed = True
+            # We won't clear the screen if we haven't printed (first loop) and it's finished
+            has_printed = False
+            while not is_finished:
+                meta, is_finished = self.get_meta_call()
+                if meta:
+                    if has_printed or not is_finished:
+                        call("clear")
+                    print(meta.format(**kwargs))
+                    has_printed = True
 
-            if not is_finished:
-                time.sleep(seconds)
+                if seconds < 0:
+                    is_finished = True
+
+                if not is_finished:
+                    time.sleep(seconds)
+        except KeyboardInterrupt:
+            pass
 
     def poll_stored_metadata_with_blessed(self, blessed, seconds=1):
 
@@ -568,7 +595,11 @@ class WorkflowManager:
                     "Skipping database config as '--no-database' option was provided."
                 )
 
-        engine.start_engine(additional_cromwell_options=additional_cromwell_params)
+        engine_is_started = engine.start_engine(
+            additional_cromwell_options=additional_cromwell_params
+        )
+        if engine_is_started is False or engine_is_started is None:
+            raise Exception(f"The engine '{engine.id()}' was not be started, returning")
         # Write the new engine details back into the database (for like PID, host and is_started)
         self.database.workflowmetadata.engine = engine
 
@@ -601,6 +632,44 @@ class WorkflowManager:
             username="root", url=f"127.0.0.1:{port}"
         )
 
+    @staticmethod
+    def prepare_container_override(
+        tool: Tool, container_override: Optional[dict], skip_digest_cache=False
+    ):
+        from janis_assistant.data.container import get_digests_from_containers
+
+        containermap = tool.containers()
+        if container_override:
+            containermap.update(container_override)
+
+        reverse_lookup = {}
+        for versioned_toolid, container in containermap.items():
+            if container is None:
+                continue
+            key = container.lower()
+            reverse_lookup[key] = reverse_lookup.get(key, []) + [versioned_toolid]
+
+        containers_to_lookup = list(reverse_lookup.keys())
+        Logger.info(
+            f"Looking up digests for {len(containers_to_lookup)} containers (this might take a few minutes...)"
+        )
+        digest_map = get_digests_from_containers(containers_to_lookup)
+        Logger.info(f"Found {len(digest_map)} digests.")
+        Logger.log("Found the following container-to-tool lookup table:")
+        Logger.log(CwlTranslator.stringify_translated_inputs(reverse_lookup))
+
+        retval = container_override or {}
+        for rawcontainer, container_digest in digest_map.items():
+            for c in reverse_lookup.get(rawcontainer, []):
+                retval[c] = container_digest
+
+        Logger.debug(
+            "Found container replacements: \n"
+            + CwlTranslator.stringify_translated_inputs(digest_map)
+        )
+
+        return retval
+
     def prepare_and_output_workflow_to_evaluate_if_required(
         self,
         tool: Tool,
@@ -614,6 +683,8 @@ class WorkflowManager:
         allow_empty_container=False,
         container_override: dict = None,
         check_files=True,
+        skip_digest_lookup=False,
+        skip_digest_cache=False,
     ) -> Tool:
         if self.database.progressDB.has(ProgressKeys.saveWorkflow):
             return Logger.info(f"Saved workflow from task '{self.wid}', skipping.")
@@ -621,6 +692,7 @@ class WorkflowManager:
         Logger.debug(f"Saving workflow with id '{tool.id()}' to {translator.name}")
 
         outdir_workflow = self.get_path_for_component(self.WorkflowManagerPath.workflow)
+
         translator.translate(
             tool,
             to_console=False,
@@ -653,6 +725,12 @@ class WorkflowManager:
             modifiers, tool, additional_inputs, hints=hints
         )
 
+        container_overrides = container_override
+        if not skip_digest_lookup:
+            container_overrides = self.prepare_container_override(
+                tool, container_override, skip_digest_cache=skip_digest_cache
+            )
+
         translator.translate(
             tool_to_evaluate,
             to_console=False,
@@ -666,31 +744,32 @@ class WorkflowManager:
             max_cores=max_cores,
             max_mem=max_memory,
             allow_empty_container=allow_empty_container,
-            container_override=container_override,
+            container_override=container_overrides,
         )
 
-        self.evaluate_output_params(
-            wf=tool_to_evaluate, additional_inputs=additional_inputs
+        mapped_inps = CwlTranslator().build_inputs_file(
+            tool_to_evaluate, recursive=False, additional_inputs=additional_inputs
         )
 
+        self.database.inputsDB.insert_inputs_from_dict(mapped_inps)
+
+        self.evaluate_output_params(wf=tool_to_evaluate, inputs=mapped_inps)
+
         self.database.progressDB.set(ProgressKeys.saveWorkflow)
         return tool_to_evaluate
 
-    def evaluate_output_params(self, wf: Tool, additional_inputs: dict):
+    def evaluate_output_params(self, wf: Tool, inputs: dict):
 
-        mapped_inps = CwlTranslator().build_inputs_file(
-            wf, recursive=False, additional_inputs=additional_inputs
-        )
         output_names: Dict[str, any] = {}
         output_folders: Dict[str, any] = {}
 
         if isinstance(wf, Workflow):
             for o in wf.output_nodes.values():
                 output_names[o.id()] = self.evaluate_output_selector(
-                    o.output_name, mapped_inps
+                    o.output_name, inputs
                 )
                 output_folders[o.id()] = self.evaluate_output_selector(
-                    o.output_folder, mapped_inps
+                    o.output_folder, inputs
                 )
 
         outputs: List[WorkflowOutputModel] = []
@@ -772,9 +851,22 @@ class WorkflowManager:
         if isinstance(engine, Cromwell):
             import json
 
-            meta = engine.raw_metadata(self.get_engine_wid()).meta
+            meta = engine.raw_metadata(self.get_engine_wid())
+            nattempts = 5
+            for at in range(nattempts):
+                if meta is None:
+                    Logger.warn(
+                        f"Engine '{engine.id()}' didn't return metadata for Janis to persist, will try {nattempts - at - 1} more times"
+                    )
+                    meta = engine.raw_metadata(self.get_engine_wid())
+                else:
+                    break
+            if meta is None:
+                Logger.critical("Cromwell didn't return metadata to persist, skipping")
+                return
+
             with open(os.path.join(metadir, "metadata.json"), "w+") as fp:
-                json.dump(meta, fp)
+                json.dump(meta.meta, fp)
 
         elif isinstance(engine, CWLTool):
             import json
@@ -803,6 +895,22 @@ class WorkflowManager:
 
         wf_outputs = self.database.outputsDB.get_all()
         engine_outputs = self.get_engine().outputs_task(self.get_engine_wid())
+
+        nattempts = 5
+        for at in range(nattempts):
+            if engine_outputs is None:
+                Logger.warn(
+                    f"Engine '{self.get_engine().id()}' didn't return outputs for Janis to copy, will try {nattempts - at - 1} more times"
+                )
+                engine_outputs = self.get_engine().outputs_task(self.get_engine_wid())
+            else:
+                break
+
+        if engine_outputs is None or len(engine_outputs) == 0:
+            return Logger.critical(
+                f"Engine '{self.get_engine().id()}' didn't return outputs for Janis to copy, skipping"
+            )
+
         eoutkeys = engine_outputs.keys()
         fs = self.environment.filescheme
 
@@ -1078,8 +1186,17 @@ class WorkflowManager:
         self.database.workflowmetadata.status = status
         self.database.commit()
         # send an email here
+        meta = self.database.get_metadata()
+        for idx in range(1, 6):
+            if meta is not None:
+                break
+            Logger.info(
+                f"Metadata was none when getting from db, sleeping for a second then will try again {5-idx} times"
+            )
+            time.sleep(1)
+            meta = self.database.get_metadata()
 
-        NotificationManager.notify_status_change(status, self.database.get_metadata())
+        NotificationManager.notify_status_change(status, meta)
 
     def save_metadata(self, meta: WorkflowModel) -> Optional[bool]:
         if not meta:
